@@ -117,6 +117,9 @@ class DrivenChrome:
                         filename += ".pdf"
                     break
                 else:
+                    for log in self.driver.get_log('browser'):
+                        print("CHROMEFAILURE: " + (log if isinstance(log, str) else json.dumps(log)))
+
                     if time_delta_ms(start_time, datetime.now()) > TIMEOUT__attachment_render:
                         raise HttpStatusException(ERR__attachment_timeout_render)
 
@@ -130,8 +133,6 @@ class DrivenChrome:
 
         if self.is_deployed:
             options.add_argument('--no-sandbox')
-            service_log_path = "log/chromedriver.log"
-            service_args = ["--log-path=%s" % service_log_path]
 
         with webdriver.Chrome(options=options, service=Service(service_args=service_args)) as driver:
             self.driver = driver
@@ -387,7 +388,7 @@ class EmailManagerService:
         if conn is None:
             raise Exception("Could not connect to email dispatcher '%s' with address '%s:%d'" % dispatcher_key, host, port)
 
-        context = ssl.SSLContext(ssl.PROTOCOL_TLS)
+        context = ssl.create_default_context()
 
         conn.starttls(context=context)
         conn.login(username, password)
@@ -443,7 +444,7 @@ class EmailManagerService:
         send_recipients = email.recipient_names
         whitelist = dispatcher_info[KG__email_dispatcher__whitelist]
 
-        if whitelist is not None and whitelist != "":
+        if whitelist is not None and whitelist != "" and os.environ.get("JAAQL_USE_EMAIL_WHITELIST") == "TRUE":
             send_to = []
             send_recipients = []
             for to, recipient in zip(email.to, email.recipient_names):
